@@ -11,9 +11,10 @@ from auto_upload.utils.uploader.carpt_upload import carpt_upload
 from auto_upload.utils.uploader.ptnap_upload import ptnap_upload
 from auto_upload.utils.uploader.wintersakura_upload import wintersakura_upload
 from auto_upload.utils.uploader.hdfans_upload import hdfans_upload
+from auto_upload.utils.uploader.hhclub_upload import hhclub_upload
 #from auto_upload.utils.uploader.hare_upload import hare_upload
 
 
 
-def auto_upload(driver,file,record_path,qbinfo,basic):
-    return eval(driver.site.sitename+'_upload(driver,file,record_path,qbinfo,basic)')
\ No newline at end of file
+def auto_upload(driver,file,record_path,qbinfo,basic,hashlist):
+    return eval(driver.site.sitename+'_upload(driver,file,record_path,qbinfo,basic,hashlist)')
\ No newline at end of file
